summaryrefslogtreecommitdiff
path: root/src/roomlist-channel.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/roomlist-channel.c')
-rw-r--r--src/roomlist-channel.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/roomlist-channel.c b/src/roomlist-channel.c
index bdaa5c99..c09a643c 100644
--- a/src/roomlist-channel.c
+++ b/src/roomlist-channel.c
@@ -247,7 +247,7 @@ salut_roomlist_channel_add_room (SalutRoomlistChannel *self,
dbus_g_type_specialized_construct (TP_STRUCT_TYPE_ROOM_INFO));
dbus_g_type_struct_set (&room,
0, handle,
- 1, "org.freedesktop.Telepathy.Channel.Type.Text",
+ 1, "im.telepathy1.Channel.Type.Text",
2, keys,
G_MAXUINT);
g_ptr_array_add (priv->rooms, g_value_get_boxed (&room));
@@ -299,7 +299,7 @@ salut_roomlist_channel_remove_room (SalutRoomlistChannel *self,
* salut_roomlist_channel_get_listing_rooms
*
* Implements D-Bus method GetListingRooms
* on interface org.freedesktop.Telepathy.Channel.Type.RoomList
*
* @error: Used to return a pointer to a GError detailing any error
* that occurred, D-Bus will throw the error only if this
@@ -324,7 +324,7 @@ salut_roomlist_channel_get_listing_rooms (TpSvcChannelTypeRoomList *iface,
* salut_roomlist_channel_list_rooms
*
* Implements D-Bus method ListRooms
* on interface org.freedesktop.Telepathy.Channel.Type.RoomList
*
* @error: Used to return a pointer to a GError detailing any error
* that occurred, D-Bus will throw the error only if this
@@ -350,7 +350,7 @@ salut_roomlist_channel_list_rooms (TpSvcChannelTypeRoomList *iface,
* salut_roomlist_channel_stop_listing
*
* Implements D-Bus method StopListing
* on interface org.freedesktop.Telepathy.Channel.Type.RoomList
*/
static void
salut_roomlist_channel_stop_listing (TpSvcChannelTypeRoomList *iface,
@@ -299,7 +299,7 @@ salut_roomlist_channel_remove_room (SalutRoomlistChannel *self,
*
* Implements D-Bus method GetListingRooms
- * on interface org.freedesktop.Telepathy.Channel.Type.RoomList
+ * on interface im.telepathy1.Channel.Type.RoomList
*
* @error: Used to return a pointer to a GError detailing any error
@@ -324,7 +324,7 @@ salut_roomlist_channel_get_listing_rooms (TpSvcChannelTypeRoomList *iface,
*
* Implements D-Bus method ListRooms
- * on interface org.freedesktop.Telepathy.Channel.Type.RoomList
+ * on interface im.telepathy1.Channel.Type.RoomList
*
* @error: Used to return a pointer to a GError detailing any error
@@ -350,7 +350,7 @@ salut_roomlist_channel_list_rooms (TpSvcChannelTypeRoomList *iface,
*
* Implements D-Bus method StopListing
- * on interface org.freedesktop.Telepathy.Channel.Type.RoomList
+ * on interface im.telepathy1.Channel.Type.RoomList
*/
static void